#Linear regression of Juvenile Cohort size (JCOH) as response variable, 
#and Proportion of Females that were Successful Breeders (FSB) as predictor variable.

attach(MDJCOH)

lm_MD_FSB_JCOH <- lm(JCOH ~ FSB)
summary(lm_MD_FSB_JCOH)

attach(MNJCOH)

lm_MN_FSB_JCOH <- lm(JCOH ~ FSB)
summary(lm_MN_FSB_JCOH)

#Linear regression of mean estimated Parturition Date (PD) OR date of first Full-Grown Juvenile (FGJ) as response variables, 
#and April index of Suitable Foraging Condition (ASFC) OR mean April Temperature in degrees Celsius (24-hour) (MT24) as predictor variables.

attach(FIG2_BrPHEN)

lm_MD_PD_ASFC <- lm(MD_PD ~ ASFC)
summary(lm_MD_PD_ASFC)

lm_MD_FGJ_ASFC <- lm(MD_FGJ ~ ASFC)
summary(lm_MD_FGJ_ASFC)

lm_MN_PD_ASFC <- lm(MN_PD ~ ASFC)
summary(lm_MN_PD_ASFC)

lm_MN_FGJ_ASFC <- lm(MN_FGJ ~ ASFC)
summary(lm_MN_FGJ_ASFC)

#see Figure 2 (ABOVE)
#see Supplementary Table S8 (BELOW)

lm_MD_PD_MT24 <- lm(MD_PD ~ MT24)
summary(lm_MD_PD_MT24)

lm_MD_FGJ_MT24 <- lm(MD_FGJ ~ MT24)
summary(lm_MD_FGJ_MT24)

lm_MN_PD_MT24 <- lm(MN_PD ~ MT24)
summary(lm_MN_PD_MT24)

lm_MN_FGJ_MT24 <- lm(MN_FGJ ~ MT24)
summary(lm_MN_FGJ_MT24)

library(mgcv)
library(AICcmodavg)

Modnames <- c("lm_MD_PD_ASFC", "lm_MD_PD_MT24")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

Modnames <- c("lm_MN_PD_ASFC", "lm_MN_PD_MT24")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

Modnames <- c("lm_MD_FGJ_ASFC", "lm_MD_FGJ_MT24")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

Modnames <- c("lm_MN_FGJ_ASFC", "lm_MN_FGJ_MT24")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable


#Model Ia (see Table 1 and Supplementary Table S2)

library(lme4)

P0 <- glmer(PREG ~ (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)

P1 <- glmer(PREG ~ SPP + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P2 <- glmer(PREG ~ ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P3 <- glmer(PREG ~ PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)

P4 <- glmer(PREG ~ SPP + ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P5 <- glmer(PREG ~ SPP + PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P6 <- glmer(PREG ~ ASFC + PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)

P7 <- glmer(PREG ~ SPP + PSFC + ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)

P8 <- glmer(PREG ~ SPP * ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P9 <- glmer(PREG ~ SPP * PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)

P10 <- glmer(PREG ~ SPP + PSFC + ASFC + SPP:PSFC  + SPP:ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P11 <- glmer(PREG ~ SPP + PSFC + ASFC + SPP:ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)
P12 <- glmer(PREG ~ SPP + PSFC + ASFC + SPP:PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ia_BRVP1)

Modnames <- c("P0", "P1", "P2", "P3", "P4", "P5", "P6", "P7", "P8", "P9", "P10", "P11", "P12")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

summary(P11)

library(ggplot2)

FIG3a <- ggplot(MODEL_Ia_BRVP1, aes(PSFC, PREG, color=SPP, shape=SPP, linetype=SPP)) + theme_bw() +
  stat_smooth(method="glm", method.args=list(family="binomial"), formula=y~x,
              alpha=0.3, size=0.5, color = "blue", aes(fill=SPP)) +
  geom_point(size = 2, position=position_jitter(height=0.02, width=0.03)) +
  xlab("PSFC") + ylab("Pregnancy Probability")

FIG3a + scale_shape_manual(values=c(21,24)) + scale_colour_manual(values=c("black", "grey50")) + scale_fill_manual(values=c("black", "grey50")) + theme(panel.grid.major.y = element_blank()) + theme(panel.grid.major.x = element_blank()) + theme(panel.grid.minor.y = element_blank()) + theme(panel.grid.minor.x = element_blank()) + theme(axis.line = element_blank())

FIG3b <- ggplot(MODEL_Ia_BRVP1, aes(ASFC, PREG, color=SPP, shape=SPP, linetype=SPP)) + theme_bw() +
  stat_smooth(method="glm", method.args=list(family="binomial"), formula=y~x,
              alpha=0.3, size=0.5, color = "blue", aes(fill=SPP)) +
  geom_point(size = 2, position=position_jitter(height=0.02, width=0.03)) +
  xlab("ASFC") + ylab("Pregnancy Probability")

FIG3b + scale_shape_manual(values=c(21,24)) + scale_colour_manual(values=c("black", "grey50")) + scale_fill_manual(values=c("black", "grey50")) + theme(panel.grid.major.y = element_blank()) + theme(panel.grid.major.x = element_blank()) + theme(panel.grid.minor.y = element_blank()) + theme(panel.grid.minor.x = element_blank()) + theme(axis.line = element_blank())


#Model Ib (see Table 1 and Supplementary Table S3)

L0 <- glmer(LACT ~ (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)

L1 <- glmer(LACT ~ SPP + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L2 <- glmer(LACT ~ ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L3 <- glmer(LACT ~ PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)

L4 <- glmer(LACT ~ SPP + ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L5 <- glmer(LACT ~ SPP + PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L6 <- glmer(LACT ~ ASFC + PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)

L7 <- glmer(LACT ~ SPP + ASFC + PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)

L8 <- glmer(LACT ~ SPP * ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L9 <- glmer(LACT ~ SPP * PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)

L10 <- glmer(LACT ~ SPP + ASFC + PSFC + SPP:ASFC + SPP:PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L11 <- glmer(LACT ~ SPP + ASFC + PSFC + SPP:ASFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)
L12 <- glmer(LACT ~ SPP + ASFC + PSFC + SPP:PSFC + (1|fYR), family = binomial(link = "logit"), data = MODEL_Ib_BRVL1)

Modnames <- c("L0", "L1", "L2", "L3", "L4", "L5", "L7", "L8", "L9", "L10", "L11", "L12")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

summary(L12)

FIG3c <- ggplot(MODEL_Ib_BRVL1, aes(ASFC, LACT, color=SPP, shape=SPP, linetype=SPP)) + theme_bw() +
  stat_smooth(method="glm", method.args=list(family="binomial"), formula=y~x,
              alpha=0.3, size=0.5, color = "blue", aes(fill=SPP)) +
  geom_point(size = 2, position=position_jitter(height=0.02, width=0.03)) +
  xlab("ASFC") + ylab("Lactation Probability")

FIG3c + scale_shape_manual(values=c(21,24)) + scale_colour_manual(values=c("black", "grey50")) + scale_fill_manual(values=c("black", "grey50")) + theme(panel.grid.major.y = element_blank()) + theme(panel.grid.major.x = element_blank()) + theme(panel.grid.minor.y = element_blank()) + theme(panel.grid.minor.x = element_blank()) + theme(axis.line = element_blank())


#Model II (see Table 1 and Supplementary Table S4)

library(optimx)

control3 = glmerControl(optimizer = "optimx", calc.derivs = FALSE,
                        
                        optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE))

MODEL_II_BRVLA$AGE <- factor(MODEL_II_BRVLA$ACLII)

LA0 <- glmer(LACT ~ (1|IND)  + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA1 <- glmer(LACT ~ SPP + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA2 <- glmer(LACT ~ AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA3 <- glmer(LACT ~ ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA4 <- glmer(LACT ~ PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA5 <- glmer(LACT ~ SPP + AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA6 <- glmer(LACT ~ SPP + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA7 <- glmer(LACT ~ SPP + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA8 <- glmer(LACT ~ AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA9 <- glmer(LACT ~ AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA10 <- glmer(LACT ~ ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA11 <- glmer(LACT ~ SPP + AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA12 <- glmer(LACT ~ SPP + AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA13 <- glmer(LACT ~ AGE + ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA14 <- glmer(LACT ~ SPP + AGE + ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA15 <- glmer(LACT ~ SPP * AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA16 <- glmer(LACT ~ SPP * AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA17 <- glmer(LACT ~ SPP * AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA18 <- glmer(LACT ~ SPP * AGE + ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA19 <- glmer(LACT ~ SPP * ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA20 <- glmer(LACT ~ SPP * ASFC + AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA21 <- glmer(LACT ~ SPP * ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA22 <- glmer(LACT ~ SPP * ASFC + AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA23 <- glmer(LACT ~ SPP * PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA24 <- glmer(LACT ~ SPP * PSFC + AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA25 <- glmer(LACT ~ SPP * PSFC + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA26 <- glmer(LACT ~ SPP * PSFC + AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA27 <- glmer(LACT ~ AGE * ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA28 <- glmer(LACT ~ AGE * ASFC + SPP + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA29 <- glmer(LACT ~ AGE * ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA30 <- glmer(LACT ~ AGE * ASFC + SPP + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA31 <- glmer(LACT ~ AGE * PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA32 <- glmer(LACT ~ AGE * PSFC + SPP + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA33 <- glmer(LACT ~ AGE * PSFC + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA34 <- glmer(LACT ~ AGE * PSFC + SPP + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA35 <- glmer(LACT ~ SPP * AGE + ASFC + AGE:ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA36 <- glmer(LACT ~ SPP * AGE + ASFC + AGE:ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA37 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA38 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)

LA39 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + AGE:ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)
LA40 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + AGE:ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_II_BRVLA)


Modnames <- c("LA0", "LA1", "LA2", "LA3", "LA4", "LA5", "LA6", "LA7", "LA8", "LA9", "LA10", "LA11", "LA12", "LA13", "LA14", "LA15", "LA16", "LA17", "LA18", "LA19", "LA20", "LA21", "LA22", "LA23", "LA24", "LA25", "LA26", "LA27", "LA28", "LA29", "LA30", "LA31", "LA32", "LA33", "LA34", "LA35", "LA36", "LA37", "LA38", "LA39", "LA40")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

summary(LA11)


#Model III (see Table 1 and Supplementary Table S6)

MODEL_III_BRVLY$AGE <- factor(MODEL_III_BRVLY$ACLIII)

LY0 <- glmer(LACT ~ (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY1 <- glmer(LACT ~ SPP + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY2 <- glmer(LACT ~ AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY3 <- glmer(LACT ~ ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY4 <- glmer(LACT ~ PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY5 <- glmer(LACT ~ SPP + AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY6 <- glmer(LACT ~ SPP + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY7 <- glmer(LACT ~ SPP + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY8 <- glmer(LACT ~ AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY9 <- glmer(LACT ~ AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY10 <- glmer(LACT ~ ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY11 <- glmer(LACT ~ SPP + AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY12 <- glmer(LACT ~ SPP + AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY13 <- glmer(LACT ~ AGE + ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY14 <- glmer(LACT ~ SPP + AGE + ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY15 <- glmer(LACT ~ SPP * AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY16 <- glmer(LACT ~ SPP * AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY17 <- glmer(LACT ~ SPP * AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY18 <- glmer(LACT ~ SPP * AGE + ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY19 <- glmer(LACT ~ SPP * ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY20 <- glmer(LACT ~ SPP * ASFC + AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY21 <- glmer(LACT ~ SPP * ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY22 <- glmer(LACT ~ SPP * ASFC + AGE + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY23 <- glmer(LACT ~ SPP * PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY24 <- glmer(LACT ~ SPP * PSFC + AGE + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY25 <- glmer(LACT ~ SPP * PSFC + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY26 <- glmer(LACT ~ SPP * PSFC + AGE + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY27 <- glmer(LACT ~ AGE * ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY28 <- glmer(LACT ~ AGE * ASFC + SPP + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY29 <- glmer(LACT ~ AGE * ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY30 <- glmer(LACT ~ AGE * ASFC + SPP + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY31 <- glmer(LACT ~ AGE * PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY32 <- glmer(LACT ~ AGE * PSFC + SPP + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY33 <- glmer(LACT ~ AGE * PSFC + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY34 <- glmer(LACT ~ AGE * PSFC + SPP + ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY35 <- glmer(LACT ~ SPP * AGE + ASFC + AGE:ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY36 <- glmer(LACT ~ SPP * AGE + ASFC + AGE:ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY37 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY38 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)

LY39 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + AGE:ASFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)
LY40 <- glmer(LACT ~ SPP * AGE + ASFC + SPP:ASFC + AGE:ASFC + PSFC + (1|IND) + (1|fYR), family = binomial(link = "logit"), control=control3, data = MODEL_III_BRVLY)


Modnames <- c("LY0", "LY1", "LY2", "LY3", "LY4", "LY5", "LY6", "LY7", "LY8", "LY9", "LY10", "LY11", "LY12", "LY13", "LY14", "LY15", "LY16", "LY17", "LY18", "LY19", "LY20", "LY21", "LY22", "LY23", "LY24", "LY25", "LY26", "LY27", "LY28", "LY29", "LY30", "LY31", "LY32", "LY33", "LY34", "LY35", "LY36", "LY37", "LY38", "LY39", "LY40")
ModList <- mget(Modnames)
AICtable <- aictab(ModList, second.ord = TRUE, sort = TRUE)
AICtable

summary(M11)


ACL2 <- subset(MODEL_III_BRVLY, MODEL_III_BRVLY$AGE=="2")

FIG3d <- ggplot(ACL2, aes(ASFC, LACT, color=SPP, shape=SPP, linetype=SPP)) + theme_bw() +
  stat_smooth(method="glm", method.args=list(family="binomial"), formula=y~x,
              alpha=0.3, size=0.5, color = "blue", aes(fill=SPP)) +
  geom_point(size = 2, position=position_jitter(height=0.02, width=0.03)) +
  xlab("ASFC") + ylab("Lactation Probability")

FIG3d + scale_shape_manual(values=c(21,24)) + scale_colour_manual(values=c("black", "grey50")) + scale_fill_manual(values=c("black", "grey50")) + theme(panel.grid.major.y = element_blank()) + theme(panel.grid.major.x = element_blank()) + theme(panel.grid.minor.y = element_blank()) + theme(panel.grid.minor.x = element_blank()) + theme(axis.line = element_blank())
